ZnDraw documentation
====================

A python-first visualisation and editing tool for atomic structures.

Installation
------------

ZnDraw can be installed via pip:

.. code:: console

   $ pip install zndraw

Usage
-----
You can use the command line interface to visualise atomic structures.
ZnDraw uses a local web server to display the visualisation and runs in your default web browser.
You can use port forwarding to access the visualisation from a remote machine.

.. code:: console

      $ zndraw file.xyz


.. toctree::
   :maxdepth: 2
   :hidden:

   python-api
   adventofcode
